#!/bin/bash
#10-11-2019.
#Script to deploy new app on ECS Cluster.

REGION="eu-west-1"
S3_URL="s3://tfm-reservas/"
DESIRED_COUNT="0"
NAME="td-reservas"
CLUSTER="reservas-cluster"
SERVICE_NAME="s-reservas"
APPVERSION="reservas.jar"
FAMILY="td-reservas"


#Get task id
TASK_ID=`aws ecs list-tasks --cluster ${CLUSTER} --family ${FAMILY} --region ${REGION}  | jq .taskArns[] | awk -F/ '{print $2}' | cut -d "\"" -f1 | tail -1`

REVISION=`aws ecs describe-task-definition --task-definition ${NAME} --region ${REGION}  | jq .taskDefinition.revision`

#Update service to desired-count=0
aws ecs update-service --cluster ${CLUSTER} --region ${REGION} --service ${SERVICE_NAME} --task-definition ${FAMILY}:${REVISION} --desired-count ${DESIRED_COUNT} 1>/dev/null

#Stop task if TASK_ID is not null
if [ -n $TASK_ID ]; then
  aws ecs stop-task --cluster ${CLUSTER} --task ${TASK_ID} --region ${REGION}
  #Wait until task is Stopped
  aws ecs wait tasks-stopped --cluster ${CLUSTER} --tasks ${TASK_ID} --region ${REGION}
fi

#Change war o jar to deploy
#APPTOCHANGE=$(cat ${NAME}.json | grep "s3://" | grep deploy | awk -F/ '{print $4}' | cut -d "\"" -f1)
#sed -e "s;${APPTOCHANGE};${APPVERSION};g" ${NAME}.json > ${NAME}-tmp.json

#Create new task revison
aws ecs register-task-definition --family ${FAMILY} --region ${REGION} --cli-input-json file:///var/lib/jenkins/${NAME}.json --region ${REGION} 1>/dev/null
REVISION=`aws ecs describe-task-definition --task-definition ${NAME} --region ${REGION}  | jq .taskDefinition.revision`

#Update service
DESIRED_COUNT="1"
aws ecs update-service --cluster ${CLUSTER} --region ${REGION}  --service ${SERVICE_NAME} --task-definition ${FAMILY}:${REVISION} --desired-count ${DESIRED_COUNT} --output table

STATUS=`aws ecs describe-services --cluster ${CLUSTER} --service ${SERVICE_NAME} --region ${REGION}  | jq .services[].events[].message | head -1 | grep steady`
echo -n
echo "${STATUS}"

#Wait 1 minute before new task is staring
echo "Waiting to start new task with app "${APPVERSION}""
sleep 60
STATUS=`aws ecs describe-services --cluster ${CLUSTER} --service ${SERVICE_NAME} --region ${REGION}  | jq .services[].events[].message | head -1`
echo "${STATUS}"

#Check last event and steady state
STATUS=`aws ecs describe-services --cluster ${CLUSTER} --service ${SERVICE_NAME} --region ${REGION}  | jq .services[].events[].message | head -1 | grep steady`

while [ -z "${STATUS}" ]
  do
        sleep 15
        STATUS=`aws ecs describe-services --cluster ${CLUSTER} --service ${SERVICE_NAME} --region ${REGION}  | jq .services[].events[].message | head -1 | grep steady`
    LASTSTATUS=`aws ecs describe-services --cluster ${CLUSTER} --service ${SERVICE_NAME} --region ${REGION}  | jq .services[].events[].message | head -1`
        if [ -n "${STATUS}" ]; then
                echo "Deploy has finished OK. "${STATUS}""
                exit 0
        #else
                #echo ""${LASTSTATUS}". Checking again in 15 seconds..."
        fi
  done